@@ -22,6 +22,9 @@ a(0):.
 0x0
 #? ['and', 'or', 'if', 'is', 'in', 'not']
 1j
+x = None()
+#?
+x
 
 # -----------------
 # if/else/elif
@@ -151,6 +154,9 @@ def global_define():
 #? int()
 global_var_in_func
 
+#? ['global_var_in_func']
+global_var_in_f
+
 
 def funct1():
     # From issue #610
@@ -172,6 +178,7 @@ def init_global_var_predefined():
 #? int() None
 global_var_predefined
 
+
 # -----------------
 # within docstrs
 # -----------------
