@@ -30,13 +30,17 @@ def sphinxy(a, b, c, d, x):
 sphinxy()
 
 # wrong declarations
-def sphinxy2(a, b, x):
+def sphinxy2(a, b, x, y, z):
     """
     :param a: Forgot type declaration
     :type a:
     :param b: Just something
     :type b: ``
     :param x: Just something without type
+    :param y: A function
+    :type y: def l(): pass
+    :param z: A keyword
+    :type z: return
     :rtype:
     """
     #? 
@@ -45,10 +49,25 @@ def sphinxy2(a, b, x):
     b
     #?
     x
+    #?
+    y
+    #?
+    z
 
 #? 
 sphinxy2()
 
+
+def sphinxy_param_type_wrapped(a):
+    """
+    :param str a:
+        Some description wrapped onto the next line with no space after the
+        colon.
+    """
+    #? str()
+    a
+
+
 # local classes -> github #370
 class ProgramNode():
     pass
@@ -177,3 +196,59 @@ d = ''
 """ bsdf """
 #? str()
 d.upper()
+
+# -----------------
+# class docstrings
+# -----------------
+
+class InInit():
+    def __init__(self, foo):
+        """
+        :type foo: str
+        """
+        #? str()
+        foo
+
+
+class InClass():
+    """
+    :type foo: str
+    """
+    def __init__(self, foo):
+        #? str()
+        foo
+
+
+class InBoth():
+    """
+    :type foo: str
+    """
+    def __init__(self, foo):
+        """
+        :type foo: int
+        """
+        #? str() int()
+        foo
+
+
+def __init__(foo):
+    """
+    :type foo: str
+    """
+    #? str()
+    foo
+
+
+# -----------------
+# Renamed imports (#507)
+# -----------------
+
+import datetime
+from datetime import datetime as datetime_imported
+
+def import_issues(foo):
+    """
+    @type foo: datetime_imported
+    """
+    #? datetime.datetime()
+    foo
