@@ -49,6 +49,8 @@ def scope_nested():
 
     #? float()
     import_tree.pkg.mod1.a
+    #? ['a', 'foobar', '__name__', '__package__', '__file__', '__doc__']
+    a = import_tree.pkg.mod1.
 
     import import_tree.random
     #? set
@@ -75,6 +77,7 @@ def scope_from_import_variable():
     without the use of ``sys.modules`` modifications (e.g. ``os.path`` see also
     github issue #213 for clarification.
     """
+    a = 3
     #? 
     from import_tree.mod2.fake import a
     #? 
@@ -277,6 +280,17 @@ def underscore():
     #? str()
     keyword.__file__
 
-    # Does that also work for the our own module?
+    # Does that also work for our own module?
     #? ['__file__']
     __file__
+
+
+# -----------------
+# complex relative imports #784
+# -----------------
+def relative():
+    #? ['foobar']
+    from import_tree.pkg.mod1 import foobar
+    #? int()
+    foobar
+    return 1
